pub struct XCr0Flags(/* private fields */);Expand description
Implementations
Sourceimpl XCr0Flags
impl XCr0Flags
Sourcepub const SSE: Self
pub const SSE: Self
Enables using MXCSR and the XMM registers
with XSAVE/XRSTOR.
Must be set if AVX is set.
Sourcepub const AVX: Self
pub const AVX: Self
Enables AVX instructions and using the upper halves of the AVX registers
with XSAVE/XRSTOR.
Sourcepub const BNDREG: Self
pub const BNDREG: Self
Enables MPX instructions and using the BND0-BND3 bound registers
with XSAVE/XRSTOR (Intel Only).
Sourcepub const BNDCSR: Self
pub const BNDCSR: Self
Enables MPX instructions and using the BNDCFGU and BNDSTATUS registers
with XSAVE/XRSTOR (Intel Only).
Sourcepub const OPMASK: Self
pub const OPMASK: Self
Enables AVX-512 instructions and using the K0-K7 mask registers
with XSAVE/XRSTOR (Intel Only).
Sourcepub const ZMM_HI256: Self
pub const ZMM_HI256: Self
Enables AVX-512 instructions and using the upper halves of the lower ZMM registers
with XSAVE/XRSTOR (Intel Only).
Sourceimpl XCr0Flags
impl XCr0Flags
Sourcepub const fn bits(&self) -> u64
pub const fn bits(&self) -> u64
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: u64) -> Option<Self>
pub const fn from_bits(bits: u64) -> Option<Self>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: u64) -> Self
pub const fn from_bits_truncate(bits: u64) -> Self
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: u64) -> Self
pub const fn from_bits_retain(bits: u64) -> Self
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<Self>
pub fn from_name(name: &str) -> Option<Self>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: Self) -> bool
pub const fn intersects(&self, other: Self) -> bool
Whether any set bits in other are also set in self.
Sourcepub const fn contains(&self, other: Self) -> bool
pub const fn contains(&self, other: Self) -> bool
Whether all set bits in other are also set in self.
Sourcepub fn remove(&mut self, other: Self)
pub fn remove(&mut self, other: Self)
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: Self)
pub fn toggle(&mut self, other: Self)
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub fn set(&mut self, other: Self, value: bool)
pub fn set(&mut self, other: Self, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(self, other: Self) -> Self
pub const fn intersection(self, other: Self) -> Self
The bitwise and (&) of the bits in self and other.
Sourcepub const fn union(self, other: Self) -> Self
pub const fn union(self, other: Self) -> Self
The bitwise or (|) of the bits in self and other.
Sourcepub const fn difference(self, other: Self) -> Self
pub const fn difference(self, other: Self) -> Self
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(self, other: Self) -> Self
pub const fn symmetric_difference(self, other: Self) -> Self
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub const fn complement(self) -> Self
pub const fn complement(self) -> Self
The bitwise negation (!) of the bits in self, truncating the result.
Sourceimpl XCr0Flags
impl XCr0Flags
Sourcepub const fn iter(&self) -> Iter<XCr0Flags>
pub const fn iter(&self) -> Iter<XCr0Flags>
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<XCr0Flags>
pub const fn iter_names(&self) -> IterNames<XCr0Flags>
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.